<?php /**
 * Functions file
 *
 * @category WordPress
 * @package  Canary
 * @author   Linesh Jose <lineshjos@gmail.com>
 * @license  http://www.gnu.org/copyleft/gpl.html GNU General Public License
 * @link     https://linesh.com/projects/canary/
 *
 */

// canary sidebarsetup --------------->
function canary_sidebars(){
	$sidebars=array(
			array(
			'name'          => __( 'Canary Widget Area', 'canary' ),
			'id'            => 'canary_sidebar',
			'description'   => __( 'Add widgets here to appear in your sidebar.', 'canary' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) 	
	);
	return $sidebars;
}


// Customizer settings ----------->
function canary_customize_partial_blogname() {
	bloginfo( 'name' );
}
function canary_customize_partial_blogdescription() {
	bloginfo( 'description' );
}



// checking for active sidebar  ----------->
function canary_active_sidebars(){
	foreach(canary_sidebars() as $sidebar){
		if ( is_active_sidebar($sidebar['id']) ) {
			return true ;
		}else{
			continue;
		}
	}
	return false;
}


// Post entery metas --------------->
	function canary_entry_meta()
	{
		echo '<ul>';
		// sticky post ------------->	
		if ( is_sticky() && is_home() && ! is_paged() ) {
			echo '<li class="sticky-post"><i class="fa fa-bookmark"></i>'.esc_html__( 'Featured', 'canary' ).'</li>';
		}
	
		// post format ------------->
		$format = get_post_format();
		$formats_class=array(	
				'aside'=>'file-text',
				'image'=>'image',
				'video'=>'video-camera',
				'quote'=>'quote-left', 
				'link'=>'link',
				'gallery'=>'image',
				'status'=>'thumb-tack', 
				'audio'=>'music',
				'chat'=>'commenting-o',
			 );
		
		if ( current_theme_supports( 'post-formats', $format ) ) {
			echo '<li class="entry-format '.esc_attr($format).'">
			<i class="fa fa-'.esc_attr($formats_class[$format]).'"></i>
			<span class="screen-reader-text">'.esc_html__( 'Format:','canary' ) .'</span>
			<a href="'.esc_url(get_post_format_link($format)).'" title="'.esc_attr($format).' post">'.esc_html(get_post_format_string( $format )).'</a></li>';
		}
	
		// Time ------------->
		echo '<li class="posted-on">
				<i class="fa fa-calendar"></i>
				<span class="screen-reader-text">'.esc_html__( 'Posted on:', 'canary' ).'</span>
				<a href="'.esc_url( get_permalink()).'" rel="bookmark">
					<time class="entry-date published" datetime="'.esc_attr(get_the_date('c')).'">'.get_the_date().'</time>
					<time class="updated screen-reader-text" datetime="'.esc_attr( get_the_modified_date( 'c' ) ).'">'. esc_html(get_the_modified_date()).'</time>
				</a>
			</li>';
		

	
		// Author ---->
		echo '<li class="byline author vcard">
				<i class="fa fa-user"></i>
				<span class="screen-reader-text">'. esc_html__( 'Author:', 'canary' ).'</span>
				<a class="url fn n" href="'.esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ).'">'.esc_html(get_the_author()).'</a>
			</li>';
	  
		// categories ---->
		$categories_list = get_the_category_list( ', ' );
		if ( $categories_list && canary_categorized_blog() ) {
			echo '<li class="cat-links">
				<i class="fa fa-folder-open"></i>
				<span class="screen-reader-text">'. esc_html__( 'Categories:', 'canary' ).'</span>
				'.ent2ncr($categories_list).'
			</li>';
		}
	
		// tags ---->
		$tags_list = get_the_tag_list( '', ', ' );
		if ( $tags_list ) {
			echo '<li class="tag-links">
				<i class="fa fa-tags"></i>
				<span class="screen-reader-text">'. esc_html__( 'Tags:', 'canary' ).'</span>
				'.ent2ncr($tags_list).'
			</li>';
		}
	
		// attachemnt ---->
		if ( is_attachment() && wp_attachment_is_image() ) {
			// Retrieve attachment metadata.
			$metadata = wp_get_attachment_metadata();
			echo '<li class="full-size-link">
				<i class="fa fa-link"></i>
				<span class="screen-reader-text">'.esc_html__( 'Full size link:', 'canary' ).'</span>
				<a href="'.esc_url( wp_get_attachment_url() ).'">'.esc_html($metadata['width']).' &times; '.esc_html($metadata['height']).'</a>
			</li>';
		}
	
		// Comments ---->
		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<li class="comment">
				<i class="fa fa-comments"></i>';
				comments_popup_link(esc_html__( 'Comment(s)', 'canary' ).'<span class="screen-reader-text">:&nbsp;'.get_the_title().'</span>');
			echo '</li>';
		}
	
		// Edit Link ---->
		edit_post_link( esc_html__( 'Edit', 'canary' ), '<li class="edit-link"><i class="fa fa-pencil"></i>', '</li>' ); 
		echo '</ul>';
	}
	
	function canary_categorized_blog()
	{
		if ( false === ( $all_the_cool_cats = get_transient( 'canary_categories' ) ) ) {
			// Create an array of all the categories that are attached to posts.
			$all_the_cool_cats = get_categories( array(
			  'fields'     => 'ids',
			  'hide_empty' => 1,
			  'number'     => 2,
			));
			// Count the number of categories that are attached to the posts.
			$all_the_cool_cats = count( $all_the_cool_cats );
			set_transient( 'canary_categories', $all_the_cool_cats );
		}
		if ( $all_the_cool_cats > 1 ) {
			// This blog has more than 1 category so canary_categorized_blog should return true.
			return true;
		} else {
			// This blog has only 1 category so canary_categorized_blog should return false.
			return false;
		}
	}



// Post featured image --------------->
	function canary_post_thumbnail( $size='',$id='')
	{
		if( !($size=trim($size)) ){
			$size='medium';
		}
		if( !($id=trim($id)) ){
			$id=get_the_ID();
		}
		if(has_post_thumbnail($id)){ 
			echo '<div class="entry-thumbnail">
					<a class="" href="'.esc_url(get_the_permalink()).'">'.get_the_post_thumbnail( $id, $size, array( 'alt' => get_the_title() ) ).'</a>
				</div>';
		}
	}


// Home page validation --------------->
	function canary_is_home_page(){
		if ( is_home() && is_front_page()) { 
			return true;
		}else{
			return false;	
		}
	}


// Displays the optional custom logo --------------->
	function canary_the_custom_logo() 
	{

		if ( function_exists( 'the_custom_logo' )  && has_custom_logo() ) {

				echo ' <div class="site-branding logo-active">';
				the_custom_logo();
			}else{
				echo ' <div class="site-branding">';
				if(canary_is_home_page()){
					echo '<h1 class="site-title"><a href="'.esc_url( home_url( '/' ) ).'" rel="home">'.esc_html(get_bloginfo( 'name' )).'</a></h1>';
				} else{
					echo '<p class="site-title"><a href="'.esc_url( home_url( '/' ) ).'" rel="home">'.esc_html(get_bloginfo( 'name' )).'</a></p>';
				}
				if ( $description = get_bloginfo( 'description', 'display' )){
					echo '<p class="site-description">'.esc_html($description).'</p>';
	       		}
			}
      		echo '</div>';
		}


// Author's meta ----------------> 	
	function canary_author_metas($author_id)
	{
		echo '<div class="author-metas">';
		
		if($post_count=count_user_posts($author_id)) { 
			echo '<a href='.esc_url(get_author_posts_url($author_id)).' title="'.esc_attr($post_count).' '.esc_attr('Posts', 'canary' ).'" class="posts"><i class="fa fa-thumb-tack"></i><span>'.esc_html($post_count).'</span></a>';
		}
		if($website=esc_url(get_the_author_meta('url',$author_id)) ){
			 echo '<a href="'.esc_url($website).'" rel="noopener" target="_blank" class="social web" title="'. esc_attr( 'Author\'s Website', 'canary' ).'"><i class="fa fa-globe"></i><span>'. esc_html__( 'Website', 'canary' ).'</span></a>';
		}
		echo '<a href="'.esc_url(get_author_feed_link($author_id )).'" rel="noopener"  title="'.esc_attr( 'Subscribe RSS Feed', 'canary' ).'" target="_blank" class="social rss"><i class="fa fa-rss"></i><span>'.esc_html__( 'RSS Feed', 'canary' ).'</span></a>';
		echo '<div class="clear"></div>
		</div>';
	}
?>